@@ -5,13 +5,13 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import type { IComputedValue } from "mobx";
 import { action, computed, observable } from "mobx";
-import type { UpdateChannel, UpdateChannelId } from "../update-channels";
+import type { UpdateChannel, ReleaseChannel } from "../update-channels";
 import { updateChannels } from "../update-channels";
 import defaultUpdateChannelInjectable from "./default-update-channel.injectable";
 
 export interface SelectedUpdateChannel {
   value: IComputedValue<UpdateChannel>;
-  setValue: (channelId?: UpdateChannelId) => void;
+  setValue: (channelId?: ReleaseChannel) => void;
 }
 
 const selectedUpdateChannelInjectable = getInjectable({
@@ -19,16 +19,16 @@ const selectedUpdateChannelInjectable = getInjectable({
 
   instantiate: (di): SelectedUpdateChannel => {
     const defaultUpdateChannel = di.inject(defaultUpdateChannelInjectable);
-    const state = observable.box(defaultUpdateChannel);
+    const state = observable.box<UpdateChannel>();
 
     return {
-      value: computed(() => state.get()),
+      value: computed(() => state.get() ?? defaultUpdateChannel.get()),
 
       setValue: action((channelId) => {
         const targetUpdateChannel =
           channelId && updateChannels[channelId]
             ? updateChannels[channelId]
-            : defaultUpdateChannel;
+            : defaultUpdateChannel.get();
 
         state.set(targetUpdateChannel);
       }),
