@@ -4,6 +4,12 @@
  */
 
 import { compile } from "path-to-regexp";
+import type { RouteProps } from "react-router";
+import { isDefined } from "./type-narrowing";
+
+export interface UrlRouteProps extends RouteProps {
+  path: string;
+}
 
 export interface URLParams<P extends object = {}, Q extends object = {}> {
   params?: P;
@@ -21,7 +27,7 @@ export function buildURL<P extends object = {}, Q extends object = {}>(path: str
     fragment && `#${fragment}`,
   ];
 
-  return parts.filter(Boolean).join("");
+  return parts.filter(isDefined).join("");
 }
 
 export function buildURLPositional<P extends object = {}, Q extends object = {}>(path: string) {
