@@ -4,22 +4,22 @@
  */
 import { getInjectable, lifecycleEnum } from "@ogre-tools/injectable";
 import { computed } from "mobx";
-import allowedResourcesInjectable from "../cluster-store/allowed-resources.injectable";
 import type { KubeResource } from "../rbac";
+import { allowedResourcesInjectionToken } from "../cluster-store/allowed-resources-injection-token";
 
 export type IsAllowedResource = (resource: KubeResource) => boolean;
 
 const isAllowedResourceInjectable = getInjectable({
   id: "is-allowed-resource",
 
-  instantiate: (di, resourceName: KubeResource) => {
-    const allowedResources = di.inject(allowedResourcesInjectable);
+  instantiate: (di, resourceName: string) => {
+    const allowedResources = di.inject(allowedResourcesInjectionToken);
 
     return computed(() => allowedResources.get().has(resourceName));
   },
 
   lifecycle: lifecycleEnum.keyedSingleton({
-    getInstanceKey: (di, resource: KubeResource) => resource,
+    getInstanceKey: (di, resource: string) => resource,
   }),
 });
 
