@@ -3,13 +3,11 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import { docsUrl, productName, supportUrl } from "../../common/vars";
+import { docsUrl, supportUrl } from "../../common/vars";
 import { broadcastMessage } from "../../common/ipc";
-import { openBrowser } from "../../common/utils";
 import type { MenuItemConstructorOptions } from "electron";
 import { webContents } from "electron";
 import loggerInjectable from "../../common/logger.injectable";
-import appNameInjectable from "../app-paths/app-name/app-name.injectable";
 import electronMenuItemsInjectable from "./electron-menu-items.injectable";
 import updatingIsEnabledInjectable from "../application-update/updating-is-enabled.injectable";
 import navigateToPreferencesInjectable from "../../common/front-end-routing/routes/preferences/navigate-to-preferences.injectable";
@@ -21,10 +19,12 @@ import stopServicesAndExitAppInjectable from "../stop-services-and-exit-app.inje
 import isMacInjectable from "../../common/vars/is-mac.injectable";
 import { computed } from "mobx";
 import showAboutInjectable from "./show-about.injectable";
-import applicationWindowInjectable from "../start-main-application/lens-window/application-window/application-window.injectable";
-import reloadWindowInjectable from "../start-main-application/lens-window/reload-window.injectable";
+import reloadCurrentApplicationWindowInjectable from "../start-main-application/lens-window/reload-current-application-window.injectable";
 import showApplicationWindowInjectable from "../start-main-application/lens-window/show-application-window.injectable";
 import processCheckingForUpdatesInjectable from "../application-update/check-for-updates/process-checking-for-updates.injectable";
+import openLinkInBrowserInjectable from "../../common/utils/open-link-in-browser.injectable";
+import appNameInjectable from "../../common/vars/app-name.injectable";
+import productNameInjectable from "../../common/vars/product-name.injectable";
 
 function ignoreIf(check: boolean, menuItems: MenuItemOpts[]) {
   return check ? [] : menuItems;
@@ -40,13 +40,13 @@ const applicationMenuItemsInjectable = getInjectable({
   instantiate: (di) => {
     const logger = di.inject(loggerInjectable);
     const appName = di.inject(appNameInjectable);
+    const productName = di.inject(productNameInjectable);
     const isMac = di.inject(isMacInjectable);
     const updatingIsEnabled = di.inject(updatingIsEnabledInjectable);
     const electronMenuItems = di.inject(electronMenuItemsInjectable);
     const showAbout = di.inject(showAboutInjectable);
-    const applicationWindow = di.inject(applicationWindowInjectable);
     const showApplicationWindow = di.inject(showApplicationWindowInjectable);
-    const reloadApplicationWindow = di.inject(reloadWindowInjectable, applicationWindow);
+    const reloadApplicationWindow = di.inject(reloadCurrentApplicationWindowInjectable);
     const navigateToPreferences = di.inject(navigateToPreferencesInjectable);
     const navigateToExtensions = di.inject(navigateToExtensionsInjectable);
     const navigateToCatalog = di.inject(navigateToCatalogInjectable);
@@ -54,6 +54,7 @@ const applicationMenuItemsInjectable = getInjectable({
     const navigateToAddCluster = di.inject(navigateToAddClusterInjectable);
     const stopServicesAndExitApp = di.inject(stopServicesAndExitAppInjectable);
     const processCheckingForUpdates = di.inject(processCheckingForUpdatesInjectable);
+    const openLinkInBrowser = di.inject(openLinkInBrowserInjectable);
 
     logger.info(`[MENU]: autoUpdateEnabled=${updatingIsEnabled}`);
 
@@ -260,7 +261,7 @@ const applicationMenuItemsInjectable = getInjectable({
             label: "Documentation",
             id: "documentation",
             click: async () => {
-              openBrowser(docsUrl).catch((error) => {
+              openLinkInBrowser(docsUrl).catch((error) => {
                 logger.error("[MENU]: failed to open browser", { error });
               });
             },
@@ -269,7 +270,7 @@ const applicationMenuItemsInjectable = getInjectable({
             label: "Support",
             id: "support",
             click: async () => {
-              openBrowser(supportUrl).catch((error) => {
+              openLinkInBrowser(supportUrl).catch((error) => {
                 logger.error("[MENU]: failed to open browser", { error });
               });
             },
