@@ -6,7 +6,7 @@
 import type { IComputedValue } from "mobx";
 
 export interface TrayMenuRegistration {
-  label?: string;
+  label?: string | IComputedValue<string>;
   click?: (menuItem: TrayMenuRegistration) => void;
   id?: string;
   type?: "normal" | "separator" | "submenu";
