@@ -3,13 +3,14 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import { getAppVersion } from "../../common/utils";
 import { lensSlackWeblinkId, slackUrl } from "../../common/vars";
 import type { WeblinkData } from "../../common/weblink-store";
 import type { MigrationDeclaration } from "../helpers";
+import packageJson from "../../../package.json";
 
 export default {
-  version: getAppVersion(), // Run always after upgrade
+  // TODO: replace with injection once migrations are made as injectables
+  version: packageJson.version, // Run always after upgrade
   run(store) {
     const weblinksRaw: any = store.get("weblinks");
     const weblinks = (Array.isArray(weblinksRaw) ? weblinksRaw : []) as WeblinkData[];
