@@ -5,7 +5,7 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import { workloadInjectionToken } from "../workload-injection-token";
 import { ResourceNames } from "../../../../utils/rbac";
-import navigateToPodsInjectable from "../../../../../common/front-end-routing/routes/cluster/workloads/deployments/navigate-to-deployments.injectable";
+import navigateToCronJobsInjectable from "../../../../../common/front-end-routing/routes/cluster/workloads/cron-jobs/navigate-to-cron-jobs.injectable";
 import namespaceStoreInjectable from "../../../+namespaces/store.injectable";
 import cronJobsStoreInjectable from "../../../+workloads-cronjobs/store.injectable";
 import { computed } from "mobx";
@@ -14,7 +14,7 @@ const cronJobsWorkloadInjectable = getInjectable({
   id: "cron-jobs-workload",
 
   instantiate: (di) => {
-    const navigate = di.inject(navigateToPodsInjectable);
+    const navigate = di.inject(navigateToCronJobsInjectable);
     const namespaceStore = di.inject(namespaceStoreInjectable);
     const store = di.inject(cronJobsStoreInjectable);
 
