@@ -4,9 +4,9 @@
  */
 import { getInjectable } from "@ogre-tools/injectable";
 import { computed } from "mobx";
-import type { GroupSelectOption, SelectOption } from "../../select";
 import userCreateResourceTemplatesInjectable from "./user-templates.injectable";
 import lensCreateResourceTemplatesInjectable from "./lens-templates.injectable";
+import type { GroupBase } from "react-select";
 
 export type RawTemplates = [group: string, items: [file: string, contents: string][]];
 
@@ -17,7 +17,7 @@ const createResourceTemplatesInjectable = getInjectable({
     const lensResourceTemplates = await di.inject(lensCreateResourceTemplatesInjectable);
     const userResourceTemplates = di.inject(userCreateResourceTemplatesInjectable);
 
-    return computed(() => {
+    return computed((): GroupBase<{ label: string; value: string }>[] => {
       const res = [
         ...userResourceTemplates.get(),
         lensResourceTemplates,
@@ -26,7 +26,7 @@ const createResourceTemplatesInjectable = getInjectable({
       return res.map(([group, items]) => ({
         label: group,
         options: items.map(([label, value]) => ({ label, value })),
-      }) as GroupSelectOption<SelectOption<string>>);
+      }));
     });
   },
 });
